==> sunclock-3.52.tgz: share/sunclock/i18n/Sunclock.pl <==
# Polish
# Day names
Nie
Pon
Wto
ro
Czw
Pi
Sob
# Month names
Sty
Lut
Mar
Kwi
Maj
Cze
Lip
Sie
Wrz
Pa
Lis
Gru
# Additional labels
Pozycja
Czas GMT
Czas soneczny
Czas lokalny
Dugo dnia
Wschd soca
Zachd soca
#
sekund
minuta
godzina
dzie
dni
#
Kliknij na miasto
Kliknij na lokacj
Kliknij kolejno na dwie lokacje (przecignij)
Kliknij dwukrotnie lub nacinij przycisk Tab dla  ' "
#
Klawisz
Opcje klawiatury/myszy
Wyjd
Wyjd z menu
Nieznane skojarzenie klawisza !!
Synchro
Warto =
Globalna zmiana czasu =
#
Nazwa miasta
Strefa czasowa
Szeroko g.
Dugo geog.
Wielko
Ostrzeenie: %s, sze = %s du = %s%sju jest na licie miast !!
Zastpowanie poprzedniego wpisu dla %s
#
Opcja
Aktywowanie wybranej opcji...
Opcja jest niepoprawna lub nie jest dostpna podczas uruchamiania !!
Opcje: wcinij <Ctrl><Spacja> aby uzyska woln przestrze wewntrz elementu
(raz)
(okresowo, okres %d sekund)
(z gwiedzistym niebem)
(puste gowne okno)
z nastpujc, raczej dug, list opcji:
Opcje znajdujce si za ** mona skonfigurowa przy uruchamianiu
Obliczanie nowego obrazu...
Sunclock posiada wiele wasnych procedur wywoywanych przez kliknicia myszy lub klawisze:
# General help
Poka pomoc i opcje (H lub kliknicie na pasku)
Wczytaj map Ziemii (F lub 2 przycisk myszy)
Powikszenie (Z lub 3 przycisk myszy)
Parametry miast
Okno komend opcji
Uyj trybu wsprzdnych
Uyj trybu czasu sonecznego
Uyj trybu odlegoci
Uyj trybu godzinnego
Uyj trybu czasu lokalnego
Zmie ustawienie czasu (w przd)
Zmie ustawienie czasu (wstecz)
Dopasuj postp czasu
Wyzeruj globaln zmian czasu
Zaznacz/usu obszar nocy
Zaznacz/usu soce i ksiyc
Zaznacz/usu poudniki
Zaznacz/usu rwnoleniki
Zaznacz/usu tropiki/rwnik/koa podbiegunowe
Otwrz nowe okno mapy
Zamknij okno
Minimalizuj okno do ikony
Odwie okno mapy
Dopasuj szeroko okna do rozmiaru ekranu
Cofnij do poprzedniego rozmiaru okna
Zamie okna zegara i mapy
Aktywuj komend (opcja -command)
Wyjd z programu
# Zoom window help
Aktywuj nowe ustawienia powikszenia
Powr do poprzednich ustawie powikszenia
Anuluj zmiany w ustawieniach powikszenia
Ustal pooenie zmieniajc rozmiar gwnego okna
Przewijaj pomidzy trybami powikszenia 0,1,2
Powiksz o wspczynnik 1.2
Oddal o wspczynnik 1/1.2 = 0.833
Powr do wspczynnika powikszenia = 1 (pena mapa)
Wyrodkuj obszar powikszenia na wybranym miecie lub lokacji
Synchronizuj operacje powikszania
# Option window help
Aktywuj opcj
Usu wiersz(e) komendy/parametru
Synchronizuj okna lub nie
Skopiuj map do gwnego okna
Usu map z gwnego okna
Rozpocznij/wstrzymaj animacj
# Urban window help
Uyj stopni, minut i sekund lub stopni dziesitnych
Szukaj/wybierz miasto
Zmie parametry miasta
Stwrz now lokacj miasta
Usu miasto
# End

==> sunclock-3.56p3.tgz: share/sunclock/i18n/Sunclock.pl <==
# Polish
# Day names
Nie
Pon
Wto
ro
Czw
Pi
Sob
# Month names
Sty
Lut
Mar
Kwi
Maj
Cze
Lip
Sie
Wrz
Pa
Lis
Gru
# Additional labels
Pozycja
Czas GMT
Czas soneczny
Czas lokalny
Dugo dnia
Wschd soca
Zachd soca
#
sekund
minuta
godzina
dzie
dni
#
Kliknij na miasto
Kliknij na lokacj
Kliknij kolejno na dwie lokacje (przecignij)
Kliknij dwukrotnie lub nacinij przycisk  dla  ' "
#
Klawisz
Opcje klawiatury/myszy
Wyjd
Wyjd z menu
Nieznane skojarzenie klawisza !!
Synchro
Warto =
Globalna zmiana czasu =
#
Nazwa miasta
Strefa czasowa
Szeroko g.
Dugo geog.
Wielko
Ostrzeenie: %s, sze = %s du = %s%sju jest na licie miast !!
Zastpowanie poprzedniego wpisu dla %s
#
Opcja
Aktywowanie wybranej opcji...
Opcja jest niepoprawna lub nie jest dostpna podczas uruchamiania !!
Opcje: wcinij <Ctrl><Spacja> aby uzyska woln przestrze wewntrz elementu
(raz)
(okresowo, okres %d sekund)
(z gwiedzistym niebem)
(puste gowne okno)
z nastpujc, raczej dug, list opcji:
Opcje znajdujce si za ** mona skonfigurowa przy uruchamianiu
Obliczanie nowego obrazu...
Sunclock posiada wiele wasnych procedur wywoywanych przez kliknicia myszy lub klawisze:
# General help
Poka pomoc i opcje (H lub kliknicie na pasku)
Wczytaj map Ziemii (F lub 2 przycisk myszy)
Powikszenie (Z lub 3 przycisk myszy)
Parametry miast
Okno komend opcji
Uyj trybu wsprzdnych
Uyj trybu czasu sonecznego
Uyj trybu odlegoci
Uyj trybu godzinnego
Uyj trybu czasu lokalnego
Zmie ustawienie czasu (w przd)
Zmie ustawienie czasu (wstecz)
Dopasuj postp czasu
Wyzeruj globaln zmian czasu
Zaznacz/usu obszar nocy
Zaznacz/usu soce i ksiyc
Zaznacz/usu poudniki
Zaznacz/usu rwnoleniki
Zaznacz/usu tropiki/rwnik/koa podbiegunowe
Otwrz nowe okno mapy
Zamknij okno
Minimalizuj okno do ikony
Odwie okno mapy
Dopasuj szeroko okna do rozmiaru ekranu
Cofnij do poprzedniego rozmiaru okna
Zamie okna zegara i mapy
Aktywuj komend (opcja -command)
Wyjd z programu
# Zoom window help
Aktywuj nowe ustawienia powikszenia
Powr do poprzednich ustawie powikszenia
Anuluj zmiany w ustawieniach powikszenia
Ustal pooenie zmieniajc rozmiar gwnego okna
Przewijaj pomidzy trybami powikszenia 0,1,2
Powiksz o wspczynnik 1.2
Oddal o wspczynnik 1/1.2 = 0.833
Powr do wspczynnika powikszenia = 1 (pena mapa)
Wyrodkuj obszar powikszenia na wybranym miecie lub lokacji
Synchronizuj operacje powikszania
# Option window help
Aktywuj opcj
Usu wiersz(e) komendy/parametru
Synchronizuj okna lub nie
Skopiuj map do gwnego okna
Usu map z gwnego okna
Rozpocznij/wstrzymaj animacj
# Urban window help
Uyj stopni, minut i sekund lub stopni dziesitnych
Szukaj/wybierz miasto
Zmie parametry miasta
Stwrz now lokacj miasta
Usu miasto
# End
